<?php

namespace Drupal\valentine\Access;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Access\AccessResultInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Routing\Access\AccessInterface;
use Symfony\Component\Routing\Route;

/**
 * Determines access to routes based on module settings.
 */
class ValentineAccessCheck implements AccessInterface {

  /**
   * Constructs a ValentineAccessCheck object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The configuration factory.
   */
  public function __construct(protected ConfigFactoryInterface $configFactory) {}

  /**
   * Checks access.
   *
   * @param \Symfony\Component\Routing\Route $route
   *   The route to check against.
   */
  public function access(Route $route): AccessResultInterface {
    $required_status = filter_var(
      $route->getRequirement('_valentine_access'),
      FILTER_VALIDATE_BOOLEAN,
    );

    $actual_status = !$this->configFactory->get('valentine.settings')
      ->get('disabled');

    return AccessResult::allowedIf($required_status === $actual_status);
  }

}
